﻿using LaserBlasterTag.entities.teams;
using LaserBlasterTag.utility;
using Otter;
using TiledSharp;

namespace LaserBlasterTag.scenes
{
    public class OneRoom : Scene
    {
        public const int _width = Global.MW;
        public const int _height = Global.MH;

        public TmxMap tmxMap = new TmxMap(Assets.ONEROOM);
        public GridCollider grid = null;

        public Tilemap layerOne = new Tilemap(Assets.TILES, _width, _height, Global.GRID_WIDTH, Global.GRID_HEIGHT);
        public Tilemap layerTwo = new Tilemap(Assets.TILES, _width, _height, Global.GRID_WIDTH, Global.GRID_HEIGHT);
        public Tilemap layerThree = new Tilemap(Assets.TILES, _width, _height, Global.GRID_WIDTH, Global.GRID_HEIGHT);
        public Tilemap layerFour = new Tilemap(Assets.TILES, _width, _height, Global.GRID_WIDTH, Global.GRID_HEIGHT);

        //public Music music = new Music(Assets.TITLE_MUSICS); //todo
        private bool _isPlaying = true;
        public OneRoom()
        {
            Global.GAME.LockAspectRatio = false;
            Global.GAME.UpdateSurfaceSize(720, 480);
            Global.GAME.CameraZoom = 6;
            #region MapCreation(title screen background creation!)
            grid = new GridCollider(_width, _height, Global.GRID_WIDTH, Global.GRID_HEIGHT, (int)Global.Type.SOLID);
            Entity gridEntity = new Entity(0, 0, null, grid);
            Add(gridEntity);
            layerOne.DefaultLayerName = tmxMap.Layers[3].Name;
            layerTwo.DefaultLayerName = tmxMap.Layers[2].Name;
            layerThree.DefaultLayerName = tmxMap.Layers[1].Name;
            layerFour.DefaultLayerName = tmxMap.Layers[0].Name;

            for (int z = 0; z < tmxMap.Layers.Count; z++)
            {
                TmxLayer layer = tmxMap.Layers[z];

                if (layer.Name == "Layer 1")
                    layerOne.AddLayer(layer.Name, tmxMap.Layers.Count - z);
                else if (layer.Name == "Layer 2")
                    layerTwo.AddLayer(layer.Name, tmxMap.Layers.Count - z);
                else if (layer.Name == "Layer 3")
                    layerThree.AddLayer(layer.Name, tmxMap.Layers.Count - z);
                else
                    layerFour.AddLayer(layer.Name, tmxMap.Layers.Count - z);

                for (int x = 0; x < tmxMap.Width; x++)
                {
                    for (int y = 0; y < tmxMap.Height; y++)
                    {
                        int i = y * tmxMap.Width + x;
                        if (layer.Name == "Layer 1")//walls
                        {
                            if (layer.Tiles[i].Gid != 0)
                                layerOne.SetTile(x, y, layer.Tiles[i].Gid - 1, layer.Name);
                            if (layer.Tiles[i].Gid != 0)
                                grid.SetTile(x, y, true);
                        }
                        else if (layer.Name == "Layer 2")//main tiles
                        {
                            if (layer.Tiles[i].Gid != 0)
                                layerTwo.SetTile(x, y, layer.Tiles[i].Gid - 1, layer.Name);
                        }
                        else if (layer.Name == "Layer 3")//nothing atm
                        {
                            if (layer.Tiles[i].Gid != 0)
                                layerThree.SetTile(x, y, layer.Tiles[i].Gid - 1, layer.Name);
                        }
                        else//nothing atm
                            layerFour.SetTile(x, y, layer.Tiles[i].Gid - 1, layer.Name);
                    }
                }
            }
            #endregion
            //add all your stuff on the screen. bottom up. or back to the front.
            AddGraphic(layerFour);
            AddGraphic(layerThree);
            AddGraphic(layerTwo);
            AddGraphic(layerOne);

            Global.player = new LaserBlasterTag.entities.Player(1380, 880);//this is the real red spawn. Time to join the blues. haha!
            //Global.player = new LaserBlasterTag.entities.Player(16, 16);//this is the blue spawn.
            Add(new RedBase(1320, 860));
            Add(new BlueBase(64, 32));
            Add(Global.player);
            SoundManager.PlayRequestedSound("_levelStarted");

            for (var i = 0; i < 100; i++)
            {
                //Add(new BlueTeamTitleScreenJunkies(Otter.Rand.Int(8, Global.GAME.Width - 64), Otter.Rand.Int(8, Global.GAME.Height - 64)));//testing
                //Add(new RedTeam(Otter.Rand.Int(8, Global.GAME.Width - 64), Otter.Rand.Int(8, Global.GAME.Height - 64)));//testing
                Add(new RedTeam(1380, 880));//testing
                Add(new BlueTeam(8, 8));
                //Add(new BlueTeam(Otter.Rand.Int(8, 100), Otter.Rand.Int(16, Global.GAME.Height - 64)));
                //use this when ready//Add(new RedTeamTitleScreenJunkies(Otter.Rand.Int(Global.GAME.Width - 150, Global.GAME.Width - 64), Otter.Rand.Int(8, Global.GAME.Height - 64)));
            }

        }

        public override void Update()
        {
            base.Update();
            //Global.cam.followPlayer(Global.MW, Global.MH, Global.PlayerX, Global.PlayerY, Global.PlayerSpeed);
            #region Mute Sounds
            if (Global.PlayerSession.Controller.Button("M").Pressed)
            {
                if (_isPlaying)
                {
                    SoundManager.isSoundEnabled = false;
                    _isPlaying = false;
                    //music.Pause();//todo
                }
                else
                {
                    SoundManager.isSoundEnabled = true;
                    _isPlaying = true;
                    //music.Play();//todo
                }
            }
            #endregion

            if (Global.PlayerSession.Controller.Button("Q").Pressed)
            {
                System.Console.WriteLine("q pressed!");
                Global.GAME.RemoveScene();
                Global.GAME.AddScene(new TitleScreen());
                Global.PlayerX = 0.0f;
                Global.PlayerY = 0.0f;
                Global.PlayerSpeed = new Speed(500);
                Global.PlayerHealth = 20;
                Global.PlayerCurrentAnim = "";
                Global.BlueBaseHealth = 5;
                Global.RedBaseHealth = 5;
            }
        }

        public override void Render()
        {
            base.Render();
            //grid.Render();
        }
    }
}
