﻿using LaserBlasterTag.entities.teams;
using LaserBlasterTag.ui;
using LaserBlasterTag.utility;
using Otter;
using TiledSharp;

namespace LaserBlasterTag.scenes
{
    class TitleScreen : Scene
    {
        public const int _width = Global.MW;
        public const int _height = Global.MH;

        public TmxMap tmxMap = new TmxMap(Assets.TITLEMAP);
        public GridCollider grid = null;

        public Tilemap layerOne = new Tilemap(Assets.TILES, _width, _height, Global.GRID_WIDTH, Global.GRID_HEIGHT);
        public Tilemap layerTwo = new Tilemap(Assets.TILES, _width, _height, Global.GRID_WIDTH, Global.GRID_HEIGHT);
        public Tilemap layerThree = new Tilemap(Assets.TILES, _width, _height, Global.GRID_WIDTH, Global.GRID_HEIGHT);
        public Tilemap layerFour = new Tilemap(Assets.TILES, _width, _height, Global.GRID_WIDTH, Global.GRID_HEIGHT);

        private bool _isTime = true;

        //public Music music = new Music(Assets.TITLE_MUSICS); //todo
        private bool _isPlaying = true;

        public TitleScreen()
        {
            Global.GAME.LockAspectRatio = false;
            Global.GAME.UpdateSurfaceSize(1440, 960);
            Global.GAME.CameraZoom = 1;
            #region MapCreation(title screen background creation!)
            grid = new GridCollider(_width, _height, Global.GRID_WIDTH, Global.GRID_HEIGHT, (int)Global.Type.SOLID);
            Entity gridEntity = new Entity(0, 0, null, grid);
            Add(gridEntity);
            layerOne.DefaultLayerName = tmxMap.Layers[3].Name;
            layerTwo.DefaultLayerName = tmxMap.Layers[2].Name;
            layerThree.DefaultLayerName = tmxMap.Layers[1].Name;
            layerFour.DefaultLayerName = tmxMap.Layers[0].Name;

            for (int z = 0; z < tmxMap.Layers.Count; z++)
            {
                TmxLayer layer = tmxMap.Layers[z];

                if (layer.Name == "Layer 1")
                    layerOne.AddLayer(layer.Name, tmxMap.Layers.Count - z);
                else if (layer.Name == "Layer 2")
                    layerTwo.AddLayer(layer.Name, tmxMap.Layers.Count - z);
                else if (layer.Name == "Layer 3")
                    layerThree.AddLayer(layer.Name, tmxMap.Layers.Count - z);
                else
                    layerFour.AddLayer(layer.Name, tmxMap.Layers.Count - z);

                for (int x = 0; x < tmxMap.Width; x++)
                {
                    for (int y = 0; y < tmxMap.Height; y++)
                    {
                        int i = y * tmxMap.Width + x;
                        if (layer.Name == "Layer 1")//walls
                        {
                            if (layer.Tiles[i].Gid != 0)
                                layerOne.SetTile(x, y, layer.Tiles[i].Gid - 1, layer.Name);
                            if (layer.Tiles[i].Gid != 0)
                                grid.SetTile(x, y, true);
                        }
                        else if (layer.Name == "Layer 2")//main tiles
                        {
                            if (layer.Tiles[i].Gid != 0)
                                layerTwo.SetTile(x, y, layer.Tiles[i].Gid - 1, layer.Name);
                        }
                        else if (layer.Name == "Layer 3")//nothing atm
                        {
                            if (layer.Tiles[i].Gid != 0)
                                layerThree.SetTile(x, y, layer.Tiles[i].Gid - 1, layer.Name);
                        }
                        else//nothing atm
                            layerFour.SetTile(x, y, layer.Tiles[i].Gid - 1, layer.Name);
                    }
                }
            }
            #endregion
            //add all your stuff on the screen. bottom up. or back to the front.
            AddGraphic(layerFour);
            AddGraphic(layerThree);
            AddGraphic(layerTwo);
            AddGraphic(layerOne);
            //there is no camera on the title screen.
            //there is no player on the title screen.
            for (var i = 0; i < 100; i++)
            {
                Add(new BlueTeamTitleScreenJunkies(Otter.Rand.Int(8, 100), Otter.Rand.Int(16, Global.GAME.Height - 64)));//testing
                Add(new RedTeamTitleScreenJunkies(Otter.Rand.Int(Global.GAME.Width - 150, Global.GAME.Width - 64), Otter.Rand.Int(8, Global.GAME.Height - 64)));//testing
                //use this when ready//Add(new BlueTeamTitleScreenJunkies(Otter.Rand.Int(8, 100), Otter.Rand.Int(16, Global.GAME.Height - 64)));
                //use this when ready//Add(new RedTeamTitleScreenJunkies(Otter.Rand.Int(Global.GAME.Width - 150, Global.GAME.Width - 64), Otter.Rand.Int(8, Global.GAME.Height - 64)));
            }

        }

        public override void Update()
        {
            base.Update();
            #region Mute Sounds
            if (Global.PlayerSession.Controller.Button("M").Pressed)
            {
                if (_isPlaying)
                {
                    SoundManager.isSoundEnabled = false;
                    _isPlaying = false;
                    //music.Pause();//todo
                }
                else
                {
                    SoundManager.isSoundEnabled = true;
                    _isPlaying = true;
                    //music.Play();//todo
                }
            }
            #endregion
            if (_isTime)
            {
                _isTime = false;
                string author = "By Commanderstitch";
                var f = .1f;
                var y = 0;
                for (var i = 0; i < author.Length; i++)
                {
                    Add(new Numbers(Global.GAME.Width / 2 - 350 + y, Global.GAME.Height - 100, author[i].ToString(), Otter.Color.Lerp(Otter.Color.Cyan, Otter.Color.Red, f)));
                    y += 40;
                    f += .05f;
                }
                var pressStart = "Press Enter to Start!";
                var z = .2f;
                var a = 0;
                for (var b = 0; b < pressStart.Length; b++)
                {
                    Add(new Numbers(Global.GAME.Width / 2 - 450 + a, Global.GAME.Height - 200, pressStart[b].ToString(), Otter.Color.Lerp(Otter.Color.Cyan, Otter.Color.Red, z)));
                    a += 40;
                    z += .05f;
                }
            }
            if (Global.PlayerSession.Controller.Button("Enter").Pressed)
            {
                Global.GAME.RemoveScene();
                Global.GAME.AddScene(new OneRoom());
            }
        }

        public override void Render()
        {
            base.Render();
            //grid.Render();
        }

    }
}
